==> voxstorm-0.1.4.tar.bz2: voxstorm-0.1.4/src/wtimedialog.h <==
/***************************************************************************/
/*! \file   wtimedialog.h
    \brief  饹WTimeDialogΥإåե롣
    \author Tomoaki Murakami
    \date   2004ǯ  5  4  16:34:12 JST
*/
/***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _WTIMEDIALOG_H_
#define _WTIMEDIALOG_H_

#include <qstring.h>
#include <qdatetimeedit.h>
#include <kdialogbase.h>
#include <krestrictedline.h>
#include <knuminput.h>

/*-------------------------------------------------------------------------*/
/*! \class  WTimeDialog
    \brief  ֻѥ
    ȥå̾ʤɤλԤ
*/
/*-------------------------------------------------------------------------*/
class WTimeDialog : public KDialogBase
{
  Q_OBJECT

public:
  //! \enum  Display
  //! \brief ֤ñ̡
  enum Display {
    Hours	= 0x01,
    Minutes	= 0x02,
    Seconds	= 0x04,
    /*Reserved = 0x08,*/
    AMPM	= 0x10,
    MilliSecs   = 0x20
  };

  //! \brief 󥹥ȥ饯
  //! \param WidgetParent ƥåȤؤΥݥ󥿡
  //! \param cName åȤ̾Ρ
  WTimeDialog(QWidget* WidgetParent=0, const char* cName=0);
  //! \brief ǥȥ饯
  ~WTimeDialog();

  //! \brief ɽ֤ñ̤ꤹ롣
  //! \param disp ɽ֤ñ̡
  void setDisplay(uint disp);
  //! \brief  ֤֤
  //! \return ֡
  QTime time() const;

public slots:
  //! \brief ɽ֤ꤹ롣
  //! \param time ֡
  void setTime(const QTime& time);

private:
  //! ꥦåȡ
  QTimeEdit* TimeEdit;
  //! ߥꥻꥦåȡ
  KIntSpinBox* IntSpinMilliSec;
};

#endif

==> voxstorm-0.3.0.tar.bz2: voxstorm-0.3.0/src/wtimedialog.h <==
/***************************************************************************/
/*! \file   wtimedialog.h
    \brief  饹WTimeDialogΥإåե롣
    \author Tomoaki Murakami
    \date   2004ǯ  5  4  16:34:12 JST
*/
/***************************************************************************/

/***************************************************************************
 *   Copyright (C) 2004 by Tomoaki Murakami                                *
 *   solarisphrere@yahoo.co.jp                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef WTIMEDIALOG_H
#define WTIMEDIALOG_H

#include <qstring.h>
#include <qdatetimeedit.h>
#include <kdialogbase.h>
#include <krestrictedline.h>
#include <knuminput.h>

/*-------------------------------------------------------------------------*/
/*! \class  WTimeDialog
    \brief  ֻѥ
    ȥå̾ʤɤλԤ
*/
/*-------------------------------------------------------------------------*/
class WTimeDialog : public KDialogBase
{
  Q_OBJECT

public:
  //! \enum  Display
  //! \brief ֤ñ̡
  enum Display {
    Hours	= 0x01,
    Minutes	= 0x02,
    Seconds	= 0x04,
    /*Reserved = 0x08,*/
    AMPM	= 0x10,
    MilliSecs   = 0x20
  };

  //! \brief 󥹥ȥ饯
  //! \param WidgetParent ƥåȤؤΥݥ󥿡
  //! \param cName åȤ̾Ρ
  WTimeDialog(QWidget* WidgetParent=0, const char* cName=0);
  //! \brief ǥȥ饯
  ~WTimeDialog();

  //! \brief ɽ֤ñ̤ꤹ롣
  //! \param disp ɽ֤ñ̡
  void setDisplay(uint disp);
  //! \brief  ֤֤
  //! \return ֡
  QTime time() const;

public slots:
  //! \brief ɽ֤ꤹ롣
  //! \param time ֡
  void setTime(const QTime& time);

private slots:
  //! \brief ꥻåȥܥ󤬲줿Υåȡ
  void slotReset();

private:
  //! ꥦåȡ
  QTimeEdit* TimeEdit;
  //! ߥꥻꥦåȡ
  KIntSpinBox* IntSpinMilliSec;
};

#endif
